from Products.Archetypes.public import *
from Products.CMFCore import CMFCorePermissions

""" 
   AmazonFolder gives you a list of Amazon items
"""

schema = BaseSchema +  Schema((
        StringField('id',
                 required=1, 
                 mode="rw",
                 accessor="getId",
                 mutator="setId",
                 default=None,
                 widget=IdWidget(
                 label="Short Name",
                 label_msgid="label_short_name",
                 description="Should not contain spaces, underscores or mixed case. "\
                 "Short Name is part of the item's web address.",
                 description_msgid="help_shortname",
                 visible={'view' : 'visible'},
                 i18n_domain="plone"),
                 ),
    StringField('title',
                required=1,
                searchable=1,
                default='',
                accessor='Title',
                widget=StringWidget(label="Title",
                                    label_msgid="label_title",
                                    description_msgid="help_title",
                                    i18n_domain="plone"),
                ),    
    StringField('description',
                isMetadata=1,
                accessor='Description',
                widget=TextAreaWidget(label='Description', 
                                description='Give a description for folder.',
                                description_msgid="help_description",
                                i18n_domain="plone"), 
               ),
    ))
        
class AmazonFolder(OrderedBaseFolder):
    """
        A folder for containing Amazon items
    """
    schema = schema
    filter_content_types = 1
    allowed_content_types = ('Amazon Item') 
    meta_type = 'AmazonFolder'
    archetype_name = 'Recommendations'
    
    content_icon = 'folder_icon.gif'
    actions = ({
       'id': 'view',
        'name': 'View',
        'action': 'string:${object_url}/amazon_listing',
        'permissions': (CMFCorePermissions.View,)
        },
        {'id': 'references',
          'name': 'References',
          'action': 'string:${object_url}/reference_edit',
          'permissions': (CMFCorePermissions.ModifyPortalContent,),
          'visible':0},
        {'id': 'metadata',
          'name': 'Properties',
          'action': 'string:${object_url}/base_metadata',
          'permissions': (CMFCorePermissions.ModifyPortalContent,),
          'visible':0})         
    
registerType(AmazonFolder)
